@@ -336,12 +336,14 @@ Window *popup_window (void);
 void set_current_window (Window * wp);
 void delete_window (Window * del_wp);
 Point window_pt (Window * wp);
+bool window_top_visible (Window * wp);
+bool window_bottom_visible (Window * wp);
 
 
 /*
  * Declare external Zile functions.
  */
 #define X(zile_name, c_name, interactive, doc)   \
-  le *F_ ## c_name (long uniarg, le * l);
+  le *F_ ## c_name (long uniarg, bool is_uniarg, le * l);
 #include "tbl_funcs.h"
 #undef X
